| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gdk.Objects.CrossingEvent
Description
No description available in the introspection data.
Synopsis
- newtype CrossingEvent = CrossingEvent (ManagedPtr CrossingEvent)
- class (BoxedPtr o, TypedObject o, IsDescendantOf CrossingEvent o) => IsCrossingEvent o
- toCrossingEvent :: (MonadIO m, IsCrossingEvent o) => o -> m CrossingEvent
- crossingEventGetDetail :: (HasCallStack, MonadIO m, IsCrossingEvent a) => a -> m NotifyType
- crossingEventGetFocus :: (HasCallStack, MonadIO m, IsCrossingEvent a) => a -> m Bool
- crossingEventGetMode :: (HasCallStack, MonadIO m, IsCrossingEvent a) => a -> m CrossingMode
Exported types
newtype CrossingEvent Source #
Memory-managed wrapper type.
Constructors
| CrossingEvent (ManagedPtr CrossingEvent) |
Instances
| Eq CrossingEvent Source # | |
Defined in GI.Gdk.Objects.CrossingEvent Methods (==) :: CrossingEvent -> CrossingEvent -> Bool # (/=) :: CrossingEvent -> CrossingEvent -> Bool # | |
| ManagedPtrNewtype CrossingEvent Source # | |
Defined in GI.Gdk.Objects.CrossingEvent Methods | |
| BoxedPtr CrossingEvent Source # | |
Defined in GI.Gdk.Objects.CrossingEvent | |
| TypedObject CrossingEvent Source # | |
Defined in GI.Gdk.Objects.CrossingEvent | |
| HasParentTypes CrossingEvent Source # | |
Defined in GI.Gdk.Objects.CrossingEvent | |
| type ParentTypes CrossingEvent Source # | |
Defined in GI.Gdk.Objects.CrossingEvent | |
class (BoxedPtr o, TypedObject o, IsDescendantOf CrossingEvent o) => IsCrossingEvent o Source #
Type class for types which can be safely cast to CrossingEvent, for instance with toCrossingEvent.
Instances
| (BoxedPtr o, TypedObject o, IsDescendantOf CrossingEvent o) => IsCrossingEvent o Source # | |
Defined in GI.Gdk.Objects.CrossingEvent | |
toCrossingEvent :: (MonadIO m, IsCrossingEvent o) => o -> m CrossingEvent Source #
Cast to CrossingEvent, for types for which this is known to be safe. For general casts, use castTo.
Methods
Overloaded methods
getDetail
crossingEventGetDetail Source #
Arguments
| :: (HasCallStack, MonadIO m, IsCrossingEvent a) | |
| => a |
|
| -> m NotifyType | Returns: the notify detail of |
Extracts the notify detail from a crossing event.
getFocus
crossingEventGetFocus Source #
Arguments
| :: (HasCallStack, MonadIO m, IsCrossingEvent a) | |
| => a |
|
| -> m Bool | Returns: |
Checks if the event surface is the focus surface.
getMode
Arguments
| :: (HasCallStack, MonadIO m, IsCrossingEvent a) | |
| => a |
|
| -> m CrossingMode | Returns: the mode of |
Extracts the crossing mode from a crossing event.