| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gdk.Objects.FocusEvent
Description
No description available in the introspection data.
Synopsis
- newtype FocusEvent = FocusEvent (ManagedPtr FocusEvent)
- class (BoxedPtr o, TypedObject o, IsDescendantOf FocusEvent o) => IsFocusEvent o
- toFocusEvent :: (MonadIO m, IsFocusEvent o) => o -> m FocusEvent
- focusEventGetIn :: (HasCallStack, MonadIO m, IsScrollEvent a) => a -> m Bool
Exported types
newtype FocusEvent Source #
Memory-managed wrapper type.
Constructors
| FocusEvent (ManagedPtr FocusEvent) |
Instances
| Eq FocusEvent Source # | |
Defined in GI.Gdk.Objects.FocusEvent | |
| ManagedPtrNewtype FocusEvent Source # | |
Defined in GI.Gdk.Objects.FocusEvent Methods | |
| BoxedPtr FocusEvent Source # | |
Defined in GI.Gdk.Objects.FocusEvent | |
| TypedObject FocusEvent Source # | |
Defined in GI.Gdk.Objects.FocusEvent | |
| HasParentTypes FocusEvent Source # | |
Defined in GI.Gdk.Objects.FocusEvent | |
| type ParentTypes FocusEvent Source # | |
Defined in GI.Gdk.Objects.FocusEvent | |
class (BoxedPtr o, TypedObject o, IsDescendantOf FocusEvent o) => IsFocusEvent o Source #
Type class for types which can be safely cast to FocusEvent, for instance with toFocusEvent.
Instances
| (BoxedPtr o, TypedObject o, IsDescendantOf FocusEvent o) => IsFocusEvent o Source # | |
Defined in GI.Gdk.Objects.FocusEvent | |
toFocusEvent :: (MonadIO m, IsFocusEvent o) => o -> m FocusEvent Source #
Cast to FocusEvent, for types for which this is known to be safe. For general casts, use castTo.
Methods
Overloaded methods
getIn
Arguments
| :: (HasCallStack, MonadIO m, IsScrollEvent a) | |
| => a |
|
| -> m Bool | Returns: |
Extracts whether this event is about focus entering or leaving the surface.