| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gdk.Objects.GrabBrokenEvent
Description
No description available in the introspection data.
Synopsis
- newtype GrabBrokenEvent = GrabBrokenEvent (ManagedPtr GrabBrokenEvent)
- class (BoxedPtr o, TypedObject o, IsDescendantOf GrabBrokenEvent o) => IsGrabBrokenEvent o
- toGrabBrokenEvent :: (MonadIO m, IsGrabBrokenEvent o) => o -> m GrabBrokenEvent
- grabBrokenEventGetGrabSurface :: (HasCallStack, MonadIO m, IsGrabBrokenEvent a) => a -> m Surface
- grabBrokenEventGetImplicit :: (HasCallStack, MonadIO m, IsGrabBrokenEvent a) => a -> m Bool
Exported types
newtype GrabBrokenEvent Source #
Memory-managed wrapper type.
Constructors
| GrabBrokenEvent (ManagedPtr GrabBrokenEvent) |
Instances
| Eq GrabBrokenEvent Source # | |
Defined in GI.Gdk.Objects.GrabBrokenEvent Methods (==) :: GrabBrokenEvent -> GrabBrokenEvent -> Bool # (/=) :: GrabBrokenEvent -> GrabBrokenEvent -> Bool # | |
| ManagedPtrNewtype GrabBrokenEvent Source # | |
Defined in GI.Gdk.Objects.GrabBrokenEvent Methods toManagedPtr :: GrabBrokenEvent -> ManagedPtr GrabBrokenEvent # | |
| BoxedPtr GrabBrokenEvent Source # | |
Defined in GI.Gdk.Objects.GrabBrokenEvent Methods boxedPtrCopy :: GrabBrokenEvent -> IO GrabBrokenEvent # boxedPtrFree :: GrabBrokenEvent -> IO () # | |
| TypedObject GrabBrokenEvent Source # | |
Defined in GI.Gdk.Objects.GrabBrokenEvent | |
| HasParentTypes GrabBrokenEvent Source # | |
Defined in GI.Gdk.Objects.GrabBrokenEvent | |
| type ParentTypes GrabBrokenEvent Source # | |
Defined in GI.Gdk.Objects.GrabBrokenEvent | |
class (BoxedPtr o, TypedObject o, IsDescendantOf GrabBrokenEvent o) => IsGrabBrokenEvent o Source #
Type class for types which can be safely cast to GrabBrokenEvent, for instance with toGrabBrokenEvent.
Instances
| (BoxedPtr o, TypedObject o, IsDescendantOf GrabBrokenEvent o) => IsGrabBrokenEvent o Source # | |
Defined in GI.Gdk.Objects.GrabBrokenEvent | |
toGrabBrokenEvent :: (MonadIO m, IsGrabBrokenEvent o) => o -> m GrabBrokenEvent Source #
Cast to GrabBrokenEvent, for types for which this is known to be safe. For general casts, use castTo.
Methods
Overloaded methods
getGrabSurface
grabBrokenEventGetGrabSurface Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGrabBrokenEvent a) | |
| => a |
|
| -> m Surface | Returns: the grab surface of |
Extracts the grab surface from a grab broken event.
getImplicit
grabBrokenEventGetImplicit Source #
Arguments
| :: (HasCallStack, MonadIO m, IsGrabBrokenEvent a) | |
| => a |
|
| -> m Bool | Returns: |
Checks whether the grab broken event is for an implicit grab.