| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gdk.Objects.MotionEvent
Description
No description available in the introspection data.
Synopsis
- newtype MotionEvent = MotionEvent (ManagedPtr MotionEvent)
- class (BoxedPtr o, TypedObject o, IsDescendantOf MotionEvent o) => IsMotionEvent o
- toMotionEvent :: (MonadIO m, IsMotionEvent o) => o -> m MotionEvent
- motionEventGetHistory :: (HasCallStack, MonadIO m, IsMotionEvent a) => a -> m (Maybe [TimeCoord])
Exported types
newtype MotionEvent Source #
Memory-managed wrapper type.
Constructors
| MotionEvent (ManagedPtr MotionEvent) |
Instances
| Eq MotionEvent Source # | |
Defined in GI.Gdk.Objects.MotionEvent | |
| ManagedPtrNewtype MotionEvent Source # | |
Defined in GI.Gdk.Objects.MotionEvent Methods | |
| BoxedPtr MotionEvent Source # | |
Defined in GI.Gdk.Objects.MotionEvent | |
| TypedObject MotionEvent Source # | |
Defined in GI.Gdk.Objects.MotionEvent | |
| HasParentTypes MotionEvent Source # | |
Defined in GI.Gdk.Objects.MotionEvent | |
| type ParentTypes MotionEvent Source # | |
Defined in GI.Gdk.Objects.MotionEvent | |
class (BoxedPtr o, TypedObject o, IsDescendantOf MotionEvent o) => IsMotionEvent o Source #
Type class for types which can be safely cast to MotionEvent, for instance with toMotionEvent.
Instances
| (BoxedPtr o, TypedObject o, IsDescendantOf MotionEvent o) => IsMotionEvent o Source # | |
Defined in GI.Gdk.Objects.MotionEvent | |
toMotionEvent :: (MonadIO m, IsMotionEvent o) => o -> m MotionEvent Source #
Cast to MotionEvent, for types for which this is known to be safe. For general casts, use castTo.
Methods
Overloaded methods
getHistory
motionEventGetHistory Source #
Arguments
| :: (HasCallStack, MonadIO m, IsMotionEvent a) | |
| => a |
|
| -> m (Maybe [TimeCoord]) | Returns: an array of time and coordinates |
Retrieves the history of the event motion, as a list of time and
coordinates.