| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gdk.Objects.TouchpadEvent
Description
No description available in the introspection data.
Synopsis
- newtype TouchpadEvent = TouchpadEvent (ManagedPtr TouchpadEvent)
- class (BoxedPtr o, TypedObject o, IsDescendantOf TouchpadEvent o) => IsTouchpadEvent o
- toTouchpadEvent :: (MonadIO m, IsTouchpadEvent o) => o -> m TouchpadEvent
- touchpadEventGetDeltas :: (HasCallStack, MonadIO m, IsTouchpadEvent a) => a -> m (Double, Double)
- touchpadEventGetGesturePhase :: (HasCallStack, MonadIO m, IsTouchpadEvent a) => a -> m TouchpadGesturePhase
- touchpadEventGetNFingers :: (HasCallStack, MonadIO m, IsTouchpadEvent a) => a -> m Word32
- touchpadEventGetPinchAngleDelta :: (HasCallStack, MonadIO m, IsTouchpadEvent a) => a -> m Double
- touchpadEventGetPinchScale :: (HasCallStack, MonadIO m, IsTouchpadEvent a) => a -> m Double
Exported types
newtype TouchpadEvent Source #
Memory-managed wrapper type.
Constructors
| TouchpadEvent (ManagedPtr TouchpadEvent) |
Instances
| Eq TouchpadEvent Source # | |
Defined in GI.Gdk.Objects.TouchpadEvent Methods (==) :: TouchpadEvent -> TouchpadEvent -> Bool # (/=) :: TouchpadEvent -> TouchpadEvent -> Bool # | |
| ManagedPtrNewtype TouchpadEvent Source # | |
Defined in GI.Gdk.Objects.TouchpadEvent Methods | |
| BoxedPtr TouchpadEvent Source # | |
Defined in GI.Gdk.Objects.TouchpadEvent | |
| TypedObject TouchpadEvent Source # | |
Defined in GI.Gdk.Objects.TouchpadEvent | |
| HasParentTypes TouchpadEvent Source # | |
Defined in GI.Gdk.Objects.TouchpadEvent | |
| type ParentTypes TouchpadEvent Source # | |
Defined in GI.Gdk.Objects.TouchpadEvent | |
class (BoxedPtr o, TypedObject o, IsDescendantOf TouchpadEvent o) => IsTouchpadEvent o Source #
Type class for types which can be safely cast to TouchpadEvent, for instance with toTouchpadEvent.
Instances
| (BoxedPtr o, TypedObject o, IsDescendantOf TouchpadEvent o) => IsTouchpadEvent o Source # | |
Defined in GI.Gdk.Objects.TouchpadEvent | |
toTouchpadEvent :: (MonadIO m, IsTouchpadEvent o) => o -> m TouchpadEvent Source #
Cast to TouchpadEvent, for types for which this is known to be safe. For general casts, use castTo.
Methods
Overloaded methods
getDeltas
touchpadEventGetDeltas Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTouchpadEvent a) | |
| => a |
|
| -> m (Double, Double) |
Extracts delta information from a touchpad event.
getGesturePhase
touchpadEventGetGesturePhase Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTouchpadEvent a) | |
| => a |
|
| -> m TouchpadGesturePhase | Returns: the gesture phase of |
Extracts the touchpad gesture phase from a touchpad event.
getNFingers
touchpadEventGetNFingers Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTouchpadEvent a) | |
| => a |
|
| -> m Word32 | Returns: the number of fingers for |
Extracts the number of fingers from a touchpad event.
getPinchAngleDelta
touchpadEventGetPinchAngleDelta Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTouchpadEvent a) | |
| => a |
|
| -> m Double | Returns: the angle delta of |
Extracts the angle delta from a touchpad pinch event.
getPinchScale
touchpadEventGetPinchScale Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTouchpadEvent a) | |
| => a |
|
| -> m Double | Returns: the scale of |
Extracts the scale from a touchpad pinch event.