| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gdk.Structs.ContentFormatsBuilder
Description
A ContentFormatsBuilder struct is an opaque struct. It is meant to
not be kept around and only be used to create new ContentFormats
objects.
Synopsis
- newtype ContentFormatsBuilder = ContentFormatsBuilder (ManagedPtr ContentFormatsBuilder)
- contentFormatsBuilderAddFormats :: (HasCallStack, MonadIO m) => ContentFormatsBuilder -> ContentFormats -> m ()
- contentFormatsBuilderAddGtype :: (HasCallStack, MonadIO m) => ContentFormatsBuilder -> GType -> m ()
- contentFormatsBuilderAddMimeType :: (HasCallStack, MonadIO m) => ContentFormatsBuilder -> Text -> m ()
- contentFormatsBuilderNew :: (HasCallStack, MonadIO m) => m ContentFormatsBuilder
- contentFormatsBuilderRef :: (HasCallStack, MonadIO m) => ContentFormatsBuilder -> m ContentFormatsBuilder
- contentFormatsBuilderToFormats :: (HasCallStack, MonadIO m) => ContentFormatsBuilder -> m ContentFormats
- contentFormatsBuilderUnref :: (HasCallStack, MonadIO m) => ContentFormatsBuilder -> m ()
Exported types
newtype ContentFormatsBuilder Source #
Memory-managed wrapper type.
Constructors
| ContentFormatsBuilder (ManagedPtr ContentFormatsBuilder) |
Instances
Methods
Overloaded methods
addFormats
contentFormatsBuilderAddFormats Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => ContentFormatsBuilder |
|
| -> ContentFormats |
|
| -> m () |
Appends all formats from formats to builder, skipping those that
already exist.
addGtype
contentFormatsBuilderAddGtype Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => ContentFormatsBuilder |
|
| -> GType |
|
| -> m () |
Appends gtype to builder if it has not already been added.
addMimeType
contentFormatsBuilderAddMimeType Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => ContentFormatsBuilder |
|
| -> Text |
|
| -> m () |
Appends mimeType to builder if it has not already been added.
new
contentFormatsBuilderNew Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => m ContentFormatsBuilder | Returns: a new |
Create a new ContentFormatsBuilder object. The resulting builder
would create an empty ContentFormats. Use addition functions to add
types to it.
ref
contentFormatsBuilderRef Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => ContentFormatsBuilder |
|
| -> m ContentFormatsBuilder | Returns: the given |
Acquires a reference on the given builder.
This function is intended primarily for bindings. ContentFormatsBuilder objects
should not be kept around.
toFormats
contentFormatsBuilderToFormats Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => ContentFormatsBuilder |
|
| -> m ContentFormats | Returns: the newly created |
Creates a new ContentFormats from the given builder.
The given ContentFormatsBuilder is reset once this function returns;
you cannot call this function multiple times on the same builder instance.
This function is intended primarily for bindings. C code should use
gdk_content_formats_builder_free_to_formats().
unref
contentFormatsBuilderUnref Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => ContentFormatsBuilder |
|
| -> m () |
Releases a reference on the given builder.